skhubness.neighbors.NNG
=======================

.. currentmodule:: skhubness.neighbors

.. autoclass:: NNG

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NNG.__init__
      ~NNG.fit
      ~NNG.get_params
      ~NNG.kneighbors
      ~NNG.set_params
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NNG.internal_distance_type
      ~NNG.valid_metrics
   
   